@@ -18,9 +18,9 @@ LANG=C rpm --checksig kernel-4.4.110-2vl6.src.rpm | grep -F ': (sha1) dsa sha1 m
 rpm -ivh kernel-4.4.110-2vl6.src.rpm || die "Can't install source package."
 
 cd ~/rpm/SOURCES/ || die "Can't chdir to ~/rpm/SOURCES/ ."
-if [ ! -r caitsith-patch-0.2-20181225.tar.gz ]
+if [ ! -r caitsith-patch-0.2-20190305.tar.gz ]
 then
-    wget -O caitsith-patch-0.2-20181225.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/66537/caitsith-patch-0.2-20181225.tar.gz' || die "Can't download patch."
+    wget -O caitsith-patch-0.2-20190305.tar.gz 'https://osdn.jp/frs/redir.php?f=/caitsith/66537/caitsith-patch-0.2-20190305.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -61,7 +61,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# CaitSith
-+tar -zxf %_sourcedir/caitsith-patch-0.2-20181225.tar.gz
++tar -zxf %_sourcedir/caitsith-patch-0.2-20190305.tar.gz
 +sed -i -e 's/CCSECURITY/CAITSITH/g' -e 's/ccsecurity/caitsith/g' -e 's/ccs_domain_info/cs_domain_info/g' -e 's/ccs_flags/cs_flags/g' patches/ccs-patch-*.diff
 +patch -sp1 < patches/ccs-patch-4.4-vine-linux-6.diff
  cp %{SOURCE10} Documentation/
