@@ -62,6 +62,9 @@
 #include <net/udp.h>
 #include <linux/ctype.h>
 #include <linux/magic.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 0, 0)
+#include <uapi/linux/mount.h>
+#endif
 
 #ifndef current_uid
 #define current_uid()   (current->uid)
